4.56. umbra.ui.widgets.messageBox — Umbra 1.0.4 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »

# 4.56. umbra.ui.widgets.messageBox

messageBox.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `messageBox()` and `standaloneMessageBox()` functions.

Others:

## 4.56.1. Module Attributes

`umbra.ui.widgets.messageBox.` `LOGGER`

## 4.56.2. Functions

`umbra.ui.widgets.messageBox.` `messageBox`(type, title, message, icon=None, buttons=1024, customButtons=None)

  This definition provides a fast GUI message box.

  Parameters: | title – Current message title. ( String ) message – Message. ( String ) icon – Custom icon. ( QConstant ) buttons – Standard buttons. ( QConstant ) customButtons – Custom buttons. ( Tuple / List )
  Returns: | User choice. ( Integer )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »